Connection Viewer

Each row in the table corresponds to a connection between a single input and a single output, so when multiple inputs are promoted to the same name, there will be multiple rows where the same output is repeated.

The table can be sorted by most columns by clicking on the column header, and a column can be filtered by typing text into the ‘filter column’ field found at the top of the column.

Differing input and output units are highlighted in red.

Columns can be shown or hidden using the toggle buttons below the table.

In the promoted input and output columns, variables that are promoted at some level in the model are shown in blue.

By default for inputs and outputs, the promoted name column is shown and the absolute name column is hidden.

When showing promoted output and promoted input columns, if the promoted output name equals the promoted input name, that means the connection is an implicit connection. Otherwise the connection is explicit, meaning somewhere in the model there is an explicit call to connect that produced the connection.

Multiple inputs are sometimes promoted to the same name, and by sorting the promoted inputs column, all such inputs will be grouped together. This can make it easier to spot either missing or unwanted implicit connections.

Clicking on the + symbol next to the name in the promoted outputs column will show additional columns (System, Output Promotion, and Input Promotion) and rows (one row per promotion) in the table to indicate where the input and/or output was promoted throughout the model. The System column shows each system where a variable was promoted up from one or more of its subsystems. The Output Promotion and Input Promotion columns show the promoted name from each promoting subsystem, relative to the system found in the System column, followed by the ↑ symbol, followed by the new promoted name in the system found in the System column. The contents of the System, Output Promotion and Input Promotion columns will be colored dark red if there is an implicit connection (promoted input name and output name match) at that system level. If neither the input nor the output have been promoted anywhere in the model, then the + symbol won't exist.

##